/*
**  CXSC is a C++ library for eXtended Scientific Computing (V 2.1)
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2005 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* CVS $Id: lx_cimath.hpp,v 1.1 2007/03/04 13:26:45 cxsc Exp $ */

/*
**
**  File: lx_cimath.hpp, 2007/04/30
**
**  Complex lx_cinterval Standard functions LibrarY, Version 1.0
**
**  Copyright (C) Frithjof Blomquist,  Blomquist@math.uni-wuppertal.de
*/


#ifndef LX_CIMATH_L_HPP_INCLUDED
#define LX_CIMATH_L_HPP_INCLUDED

#include "lx_cinterval.hpp"

namespace cxsc{

    //! Calculates \f$ [z]^2  \f$
    lx_cinterval sqr(const lx_cinterval&) throw();
    //! Calculates \f$ \sqrt{[z]}  \f$
    lx_cinterval sqrt(const lx_cinterval&) throw();
    //! Calculates \f$ \sqrt[n]{[z]} \f$
    lx_cinterval sqrt(const lx_cinterval& ,int) throw(); 
    //! Calculates \f$ \exp([z]) \f$
    lx_cinterval exp(const lx_cinterval&) throw();
	 //! Calculates \f$ 2^{[z]} \f$
	 lx_cinterval exp2(const lx_cinterval&) throw();
	 //! Calculates \f$ 10^{[z]} \f$
	 lx_cinterval exp10(const lx_cinterval&) throw();
    //! Calculates \f$ \sin([z]) \f$
    lx_cinterval sin(const lx_cinterval&) throw();
    //! Calculates \f$ \cos([z]) \f$
    lx_cinterval cos(const lx_cinterval&) throw();

    //! Calculates \f$ \cosh([z]) \f$
    lx_cinterval cosh(const lx_cinterval&) throw();
    //! Calculates \f$ \sinh([z]) \f$
    lx_cinterval sinh(const lx_cinterval&) throw();

    //! Calculates \f$ \mbox{Arg}([z]) \f$
    lx_interval Arg(const lx_cinterval&) throw();
    //! Calculates \f$ \mbox{arg}([z]) \f$
    lx_interval arg(const lx_cinterval&) throw();

    //! Calculates \f$ \ln([z]) \f$
    lx_cinterval Ln(const lx_cinterval& ) throw();
    //! Calculates \f$ \ln([z]) \f$
    lx_cinterval ln(const lx_cinterval& ) throw();
	 
    //! Calculates \f$ \mbox{log2}([z]) \f$
	 lx_cinterval log2(const lx_cinterval& ) throw();
    //! Calculates \f$ \mbox{log10}([z]) \f$
	 lx_cinterval log10(const lx_cinterval& ) throw();

    //! Calculates \f$ [z]^n \f$
    lx_cinterval power_fast( const lx_cinterval&, const real& ) throw();
    //! Calculates \f$ [z]^n \f$
    lx_cinterval power( const lx_cinterval&, const real& ) throw();

    //! Calculates \f$ [z]^{[p]} \f$
    lx_cinterval pow( const lx_cinterval& , const lx_interval& ) throw();
    //! Calculates \f$ [z]^{[w]} \f$
    lx_cinterval pow( const lx_cinterval& , const lx_cinterval& ) throw();

    //! Calculates \f$ \tan([z]) \f$
    lx_cinterval tan (const lx_cinterval& ) throw();
    //! Calculates \f$ \cot([z]) \f$
    lx_cinterval cot (const lx_cinterval& ) throw();
    //! Calculates \f$ \tanh([z]) \f$
    lx_cinterval tanh(const lx_cinterval& ) throw();
    //! Calculates \f$ \coth([z]) \f$
    lx_cinterval coth(const lx_cinterval& ) throw();

    //! Calculates \f$ \arcsin([z]) \f$
    lx_cinterval asin(const lx_cinterval& ) throw();
    //! Calculates \f$ \arccos([z]) \f$
    lx_cinterval acos(const lx_cinterval& ) throw();
    //! Calculates \f$ \arctan([z]) \f$
    lx_cinterval atan(const lx_cinterval& ) throw();
    //! Calculates \f$ \arccot([z]) \f$
    lx_cinterval acot(const lx_cinterval& ) throw();

    //! Calculates \f$ \mbox{arcsinh}([z]) \f$
    lx_cinterval asinh( const lx_cinterval& ) throw();
    //! Calculates \f$ \mbox{arccosh}([z]) \f$
    lx_cinterval acosh( const lx_cinterval& ) throw();
    //! Calculates \f$ \mbox{arctanh}([z]) \f$
    lx_cinterval atanh( const lx_cinterval& ) throw();
    //! Calculates \f$ \mbox{arccoth}([z]) \f$
    lx_cinterval acoth( const lx_cinterval& ) throw();
	 
    //! Calculates \f$ \mbox{sqrt}(1+[z]^2) \f$
	 lx_cinterval sqrt1px2(const lx_cinterval& z) throw();
    //! Calculates \f$ \mbox{sqrt}(1-[z]^2) \f$	 
	 lx_cinterval sqrt1mx2(const lx_cinterval& z) throw();
	 //! Calculates \f$ \mbox{sqrt}([z]^2-1) \f$
	 lx_cinterval sqrtx2m1(const lx_cinterval& z) throw();
	 //! Calculates \f$ \mbox{sqrt}([z]+1)-1 \f$
	 lx_cinterval sqrtp1m1(const lx_cinterval& z) throw();
	 //! Calculates \f$ \mbox{exp}([z])-1 \f$
	 lx_cinterval expm1(const lx_cinterval& z) throw();
	 //! Calculates \f$ \mbox{ln}(1+[z]) \f$	 
	 lx_cinterval lnp1(const lx_cinterval& z) throw();
	 //! Calculates \f$ \sqrt{[z]} \f$ and returns all possible solutions
	 std::list<lx_cinterval> sqrt_all( const lx_cinterval& z) throw();
	 //! Calculates \f$ \sqrt[n]{[z]} \f$ and returns all possible solutions
	 std::list<lx_cinterval> sqrt_all( const lx_cinterval& z, int n ) throw();
	 //! Calculates \f$ [z]^{[y]} \f$ and returns all possible solutions
	 std::list<lx_cinterval> pow_all( const lx_cinterval& z,
												 const lx_interval& p ) throw();
} // namespace cxsc

#endif

/*

  End of File: lx_cimath.hpp

*/
