/*
**  CXSC is a C++ library for eXtended Scientific Computing (V 2.2)
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2006 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**  F. Blomquist, University of Wuppertal, 21.05.2008;
*/

/* CVS $Id: lx_cinterval.cpp,v 1.4 2006/12/06 18:36:17 cxsc Exp $ */

#include "lx_cinterval.hpp"

namespace cxsc {

l_cinterval & l_cinterval::operator = (const lx_cinterval &a) throw()
// This operator is declared in l_cinterval.hpp !!
{
    l_interval lre,lim;
    lre = Re(a);
    lim = Im(a);
    l_cinterval lc(lre,lim);

    return (*this) = lc;
}

cinterval & cinterval::operator = (const lx_cinterval &a) throw()
// This operator is declared in cinterval.hpp !!
{
    l_cinterval lc;
    cinterval z;

    lc = a;
    z = lc;

    return (*this) = z;
}

// ------------------------ Input --------------------------------------
/*
std::string & operator >> (std::string &s, lx_cinterval &a) throw()
// Funktionierende Version mit Zweier-Exponenten
{
    lx_interval Lar, Lai;

    s = skipwhitespacessinglechar (s, '(');
    s = s >> SaveOpt >> Lar;
    s = skipwhitespacessinglechar (s, ',');
    s = s >> Lai >> RestoreOpt;
    s = skipwhitespacessinglechar (s, ')');
    s = skipwhitespaces (s); // erasing whitespaces
    a = lx_cinterval(Lar,Lai);

    return s;
}
*/
std::string & operator >> (std::string &s, lx_cinterval &a) throw()
// Funktionierende Version mit Zehner-Exponenten, z.B.
// s = ( {+1, [4,4.01]} , {-2, [7,7]} ) 
{
    lx_interval Lar, Lai;
    string str(s);
    int i;

    str = skipwhitespacessinglechar (str, '(');
    i = str.find("}");
    str.erase(i+1);
    str >> SaveOpt >> Lar;

    i = s.find("}");
    s.erase(0,i+1);
    s = skipwhitespacessinglechar (s, ',');
    s >> Lai >> RestoreOpt;
    s = "";

    a = lx_cinterval(Lar,Lai);

    return s;
}


void operator >> (const std::string &s, lx_cinterval &a) throw()
{
// Writes strings s to variable a of type lx_cinterval;
    std::string r(s);
    r >> a;
}

void operator >> (const char *s, lx_cinterval &a) throw()
{
    std::string r(s);
    r >> a;
}

std::istream & operator >> (std::istream &s, lx_cinterval &a) throw()
{
    lx_interval Lar, Lai;
    char c;
	 
	 std::cout << "Real part: {Exponent to base 10, [a,b]} = ?" 
			     << std::endl;
	 s >> Lar;
	 std::cout << "Img. part: {Exponent to base 10, [a,b]} = ?" 
			     << std::endl;	
	 s >> Lai >> RestoreOpt;
    a = lx_cinterval(Lar,Lai);

    if (!waseolnflag)
    {
		skipeolnflag = false; inpdotflag = true;
		c = skipwhitespaces (s);
		if (inpdotflag && c != ')')
	  		s.putback(c);
    }
    return s;
}


} // namespace cxsc
