/*
**  CXSC is a C++ library for eXtended Scientific Computing (V 2.2)
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2006 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**  F. Blomquist, University of Wuppertal, 20.09.2007;
*/

/* CVS $Id: lx_complex.cpp,v 1.14 2006/12/06 19:14:09 cxsc Exp $ */

#include <memory.h>
#include "lx_complex.hpp"

namespace cxsc {
	
	l_complex & l_complex::operator = (const lx_complex& a) throw()
	{
		l_real u,v;
		u = Re(a);  v = Im(a);
		return *this = l_complex(u,v);
	}
	
	complex & complex::operator = (const lx_complex& a) throw()
	{
		l_complex x;
		complex y;
		
		x = a;
		y = x;
		return *this = y;
	}

	std::string & operator >> (std::string& s, lx_complex& a) throw()
// Writes string s to variable a of type lx_complex;
// and returns an empty string s;
// Example:  s = "({2,3} , {4,5})" delivers a value a
// with:    a ~ 10^2 * 3.0 + i*10^4 * 5.0;
	{
		string su;
   	int i;
		std::cout << "Halo 1" << std::endl;
		s = skipwhitespacessinglechar (s, '(');
		std::cout << "s = " << s << std::endl;
		i = s.find("}");
		std::cout << "i = " << i << std::endl;
		su = s.substr(0,i+1);
		std::cout << "su = " << su << std::endl;
		su >> a.re;
		
		s.erase(0,i+1);
		s = skipwhitespacessinglechar (s, ',');
		std::cout << "s = " << s << std::endl;
		s >> a.im;

		s = "";
		return s;
	}
	
	void operator >> (const std::string &s, lx_complex &a) throw()
	{
   // Writes string s to variable a of type lx_real;
		std::string r(s);
		r >> a;
	}
	
	void operator >> (const char *s, lx_complex& a) throw()
	{
		std::string r(s);
		r >> a;
	}	
	
	lx_real abs  (const lx_complex& a) throw()
	{ return sqrtx2y2(a.re,a.im); }
	lx_real abs2 (const lx_complex& a) throw()
	{ return a.re*a.re + a.im*a.im; }
	
} // end: namespace cxsc
