/* 
**  CXSC is a C++ library for eXtended Scientific Computing (V 2.2)
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2006 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* CVS $Id: lx_rmath.cpp,v 1.18 2006/12/06 13:11:25 cxsc Exp $ */

#include "lx_rmath.hpp"
#include "lx_imath.hpp"
// #include <cmath> 


namespace cxsc {
	
// ---------------- lx_real constants in high accuracy --------------------

//	static real CXSC_Pi[40]; // CXSC_Pi[0], ... ,CXSC_Pi[39]
//	static bool CXSC_Pi_initialized = false;

lx_real Pi_lx_real() throw()
{ return mid(Pi_lx_interval()); }
lx_real Pip2_lx_real() throw()
{ return mid(Pip2_lx_interval()); }
lx_real Pi2r_lx_real() throw()
{ return mid(Pi2r_lx_interval()); }
lx_real Pi2_lx_real() throw()
{ return mid(Pi2_lx_interval()); }
lx_real Pid4_lx_real() throw()
{ return mid(Pid4_lx_interval()); }
lx_real Pid2_lx_real() throw()
{ return mid(Pid2_lx_interval()); }
lx_real Ln2_lx_real() throw()
{ return mid(Ln2_lx_interval()); }
lx_real Ln10_lx_real() throw()
{ return mid(Ln10_lx_interval()); }
lx_real Ln10r_lx_real() throw()
{ return mid(Ln10r_lx_interval()); }
lx_real Pir_lx_real() throw()
{ return mid(Pir_lx_interval()); }
lx_real SqrtPi_lx_real() throw()
{ return mid(SqrtPi_lx_interval()); }
lx_real Sqrt2Pi_lx_real() throw()
{ return mid(Sqrt2Pi_lx_interval()); }
lx_real Sqrt2_lx_real() throw()
{ return mid(Sqrt2_lx_interval()); }
lx_real Sqrt2r_lx_real() throw()
{ return mid(Sqrt2r_lx_interval()); }
lx_real Sqrt3_lx_real() throw()
{ return mid(Sqrt3_lx_interval()); }
lx_real Sqrt3r_lx_real() throw()
{ return mid(Sqrt3r_lx_interval()); }
lx_real Sqrt3d2_lx_real() throw()
{ return mid(Sqrt3d2_lx_interval()); }
lx_real Ln2r_lx_real() throw()
{ return mid(Ln2r_lx_interval()); }
lx_real Pid3_lx_real() throw()
{ return mid(Pid3_lx_interval()); }
lx_real SqrtPir_lx_real() throw()
{ return mid(SqrtPir_lx_interval()); }
lx_real Sqrt2Pir_lx_real() throw()
{ return mid(Sqrt2Pir_lx_interval()); }
lx_real LnPi_lx_real() throw()
{ return mid(LnPi_lx_interval()); }
lx_real Ln2Pi_lx_real() throw()
{ return mid(Ln2Pi_lx_interval()); }
lx_real E_lx_real() throw()
{ return mid(E_lx_interval()); }
lx_real Ep2r_lx_real() throw()
{ return mid(Ep2r_lx_interval()); }
lx_real Ep2_lx_real() throw()
{ return mid(Ep2_lx_interval()); }
lx_real Er_lx_real() throw()
{ return mid(Er_lx_interval()); }
lx_real EpPi_lx_real() throw()
{ return mid(EpPi_lx_interval()); }
lx_real EpPid2_lx_real() throw()
{ return mid(EpPid2_lx_interval()); }
lx_real EpPid4_lx_real() throw()
{ return mid(EpPid4_lx_interval()); }
lx_real Ep2Pi_lx_real() throw()
{ return mid(Ep2Pi_lx_interval()); }
lx_real EulerGamma_lx_real() throw()
{ return mid(EulerGamma_lx_interval()); }
lx_real Catalan_lx_real() throw()
{ return mid(Catalan_lx_interval()); }
lx_real sqrt5_lx_real() throw()
{ return mid(sqrt5_lx_interval()); }
lx_real sqrt7_lx_real() throw()
{ return mid(sqrt7_lx_interval()); }
lx_real One_m_lx_real() throw()
{ return mid(One_m_lx_interval()); }
lx_real One_p_lx_real() throw()
{ return mid(One_p_lx_interval()); }

// -------------------- lx_real functions ---------------------------------

lx_real sqrt(const lx_real& x) throw()
{ return mid(sqrt(lx_interval(x))); }
lx_real sqr(const lx_real& x) throw()
{ return mid(sqr(lx_interval(x))); }
lx_real ln(const lx_real& x) throw()
{ return mid(ln(lx_interval(x))); }
lx_real log2(const lx_real& x) throw()
{ return mid(log2(lx_interval(x))); }
lx_real log10(const lx_real& x) throw()
{ return mid(log10(lx_interval(x))); }
lx_real lnp1(const lx_real& x) throw()
{ return mid(lnp1(lx_interval(x))); }
lx_real exp(const lx_real& x) throw()
{ return mid(exp(lx_interval(x))); }
lx_real exp2(const lx_real& x) throw()
{ return mid(exp2(lx_interval(x))); }
lx_real exp10(const lx_real& x) throw()
{ return mid(exp10(lx_interval(x))); }
lx_real expm1(const lx_real& x) throw()
{ return mid(expm1(lx_interval(x))); }
lx_real power(const lx_real& x, const real& r) throw()
{ return mid(power(lx_interval(x),r)); }
lx_real pow(const lx_real& x, const lx_real& y) throw()
{ return mid(pow(lx_interval(x),lx_interval(y))); }
lx_real xp1_pow_y(const lx_real& x, const lx_real& y) throw()
{ return mid(xp1_pow_y(lx_interval(x),lx_interval(y))); }
lx_real sin(const lx_real& x) throw()
{ return mid(sin(lx_interval(x))); }
lx_real sin_n(const lx_real& x, const real& n) throw()
{ return mid(sin_n(lx_interval(x),n)); }
lx_real cos(const lx_real& x) throw()
{ return mid(cos(lx_interval(x))); }
lx_real cos_n(const lx_real& x, const real& n) throw()
{ return mid(cos_n(lx_interval(x),n)); }
lx_real tan(const lx_real& x) throw()
{ return mid(tan(lx_interval(x))); }
lx_real cot(const lx_real& x) throw()
{ return mid(cot(lx_interval(x))); }
lx_real sqrt1px2(const lx_real& x) throw()
{ return mid(sqrt1px2(lx_interval(x))); }
lx_real atan(const lx_real& x) throw()
{ return mid(atan(lx_interval(x))); }
lx_real sqrt1mx2(const lx_real& x) throw()
{ return mid(sqrt1mx2(lx_interval(x))); }
lx_real sqrtx2m1(const lx_real& x) throw()
{ return mid(sqrtx2m1(lx_interval(x))); }
lx_real asin(const lx_real& x) throw()
{ return mid(asin(lx_interval(x))); }
lx_real acos(const lx_real& x) throw()
{ return mid(acos(lx_interval(x))); }
lx_real acot(const lx_real& x) throw()
{ return mid(acot(lx_interval(x))); }
lx_real sinh(const lx_real& x) throw()
{ return mid(sinh(lx_interval(x))); }
lx_real cosh(const lx_real& x) throw()
{ return mid(cosh(lx_interval(x))); }
lx_real tanh(const lx_real& x) throw()
{ return mid(tanh(lx_interval(x))); }
lx_real coth(const lx_real& x) throw()
{ return mid(coth(lx_interval(x))); }
lx_real sqrtp1m1(const lx_real& x) throw()
{ return mid(sqrtp1m1(lx_interval(x))); }
lx_real asinh(const lx_real& x) throw()
{ return mid(asinh(lx_interval(x))); }
lx_real acosh(const lx_real& x) throw()
{ return mid(acosh(lx_interval(x))); }
lx_real acoshp1(const lx_real& x) throw()
{ return mid(acoshp1(lx_interval(x))); }
lx_real atanh(const lx_real& x) throw()
{ return mid(atanh(lx_interval(x))); }
lx_real atanh1m(const lx_real& x) throw()
{ return mid(atanh1m(lx_interval(x))); }
lx_real atanhm1p(const lx_real& x) throw()
{ return mid(atanhm1p(lx_interval(x))); }
lx_real acoth(const lx_real& x) throw()
{ return mid(acoth(lx_interval(x))); }
lx_real acothp1(const lx_real& x) throw()
{ return mid(acothp1(lx_interval(x))); }
lx_real acothm1m(const lx_real& x) throw()
{ return mid(acothm1m(lx_interval(x))); }
lx_real sqrtx2y2(const lx_real& x, const lx_real& y) throw()
{ return mid(sqrtx2y2(lx_interval(x),lx_interval(y))); }
lx_real ln_sqrtx2y2(const lx_real& x, const lx_real& y) throw()
{ return mid(ln_sqrtx2y2(lx_interval(x),lx_interval(y))); }
lx_real sqrt(const lx_real& x, int n) throw()
{ return mid(sqrt(lx_interval(x),n)); }

} // namespace cxsc
