/*
**  CXSC is a C++ library for eXtended Scientific Computing (V 2.2)
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2006 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* CVS $Id: lx_rmath.hpp,v 1.16 2006/12/06 13:11:25 cxsc Exp $ */

#ifndef LX_RMATH_HPP_L_INCLUDED
#define LX_RMATH_HPP_L_INCLUDED

#include "lx_interval.hpp"
#include <l_rmath.hpp>

namespace cxsc {
// --------------------- lx_real Konstanten ---------------------------------

    //! lx_real approximation for \f$ \pi \f$
    lx_real Pi_lx_real() throw(); // pi
	 //! lx_real approximation for \f$ \pi^2 \f$
	 lx_real Pip2_lx_real() throw(); // pi^2
	 //! lx_real approximation for \f$ 2\pi \f$
	 lx_real Pi2_lx_real() throw(); // 2*pi
	 //! lx_real approximation for \f$ \frac{\pi}{4} \f$
	 lx_real Pid4_lx_real() throw(); // Pi/4
	 //! lx_real approximation for \f$ \frac{\pi}{2} \f$
	 lx_real Pid2_lx_real() throw(); // Pi/2
    //! lx_real approximation for \f$ \ln(2) \f$
	 lx_real Ln2_lx_real() throw();
    //! lx_real approximation for \f$ \ln(10) \f$
    lx_real Ln10_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{1}{\ln(10)} \f$
	 lx_real Ln10r_lx_real() throw();
    //! lx_real approximation for \f$ \frac{1}{\pi} \f$
    lx_real Pir_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{1}{2\pi} \f$
	 lx_real Pi2r_lx_real() throw();  // 1/(2*pi)
    //! lx_real approximation for \f$ \sqrt{\pi} \f$
    lx_real SqrtPi_lx_real() throw();
    //! lx_real approximation for \f$ \sqrt{2\pi} \f$
    lx_real Sqrt2Pi_lx_real() throw();
    //! lx_real approximation for \f$ \sqrt{2} \f$
    lx_real Sqrt2_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{1}{\sqrt{2}} \f$
	 lx_real Sqrt2r_lx_real() throw();
    //! lx_real approximation for \f$ \sqrt{3} \f$
    lx_real Sqrt3_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{1}{\sqrt{3}} \f$
	 lx_real Sqrt3r_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{\sqrt{3}}{2} \f$
	 lx_real Sqrt3d2_lx_real() throw();
    //! lx_real approximation for \f$ 1/\ln(2) \f$
    lx_real Ln2r_lx_real() throw();
    //! lx_real approximation for \f$ \pi/3 \f$
    lx_real Pid3_lx_real() throw();
    //! lx_real approximation for \f$ 1/\sqrt{\pi} \f$
    lx_real SqrtPir_lx_real() throw();
    //! lx_real approximation for \f$ 1/\sqrt{2\pi} \f$
    lx_real Sqrt2Pir_lx_real() throw();
    //! lx_real approximation for \f$ \ln(\pi) \f$
    lx_real LnPi_lx_real() throw();
    //! lx_real approximation for \f$ \ln(2\pi) \f$
    lx_real Ln2Pi_lx_real() throw();
    //! lx_real approximation for \f$ e=2.718... \f$
    lx_real E_lx_real() throw();
	 //! lx_real approximation for \f$ e^2 \f$
	 lx_real Ep2_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{1}{e^2} \f$
	 lx_real Ep2r_lx_real() throw();
	 //! lx_real approximation for \f$ \frac{1}{e} \f$
	 lx_real Er_lx_real() throw();
    //! lx_real approximation for \f$ e^{\pi} \f$
    lx_real EpPi_lx_real() throw();
	 //! lx_real approximation for \f$ e^{\pi/2} \f$
	 lx_real EpPid2_lx_real() throw();
	 //! lx_real approximation for \f$ e^{\pi/4} \f$
	 lx_real EpPid4_lx_real() throw();
	 //! lx_real approximation for \f$ e^{2\pi} \f$
	 lx_real Ep2Pi_lx_real() throw();
    //! lx_real approximation for \f$ \mbox{EulerGamma}=0.5772... \f$
    lx_real EulerGamma_lx_real() throw();
    //! lx_real approximation for \f$ \mbox{Catalan=0.9159... \f$
    lx_real Catalan_lx_real() throw();
    //! lx_real approximation for \f$ \sqrt{5} \f$
    lx_real sqrt5_lx_real() throw();
    //! lx_real approximation for \f$ \sqrt{7} \f$
    lx_real sqrt7_lx_real() throw();
    //! lx_real approximation for \f$ 1-2^{-2097} \f$
    lx_real One_m_lx_real() throw();
    //! lx_real approximation for \f$ 1+2^{-2097} \f$
    lx_real One_p_lx_real() throw();

// -------------------- lx_real functions ---------------------------------

//! Calculates \f$ \sqrt{[x]}  \f$
lx_real sqrt(const lx_real&) throw();
//! Calculates \f$ [x]^2  \f$
lx_real sqr(const lx_real&) throw();
//! Calculates \f$ \ln([x]) \f$
lx_real ln(const lx_real &) throw();
//! Calculates \f$ \log2([x]) \f$
lx_real log2(const lx_real &) throw();
//! Calculates \f$ \log10([x]) \f$
lx_real log10(const lx_real &) throw();
//! Calculates \f$ \ln(1+[x]) \f$
lx_real lnp1(const lx_real &) throw();
//! Calculates \f$ \exp([x]) \f$
lx_real exp(const lx_real &) throw();
//! Calculates \f$ 2^{[x]} \f$
lx_real exp2(const lx_real &) throw(); // 2^x
//! Calculates \f$ 10^{[x]} \f$
lx_real exp10(const lx_real &) throw(); // 10^x
//! Calculates \f$ \exp([x])-1 \f$
lx_real expm1(const lx_real &x) throw(); 
//! Calculates \f$ [x]^n \f$
lx_real power(const lx_real &, const real &) throw();
//! Calculates \f$ [x]^{[y]} \f$
lx_real pow(const lx_real &, const lx_real &) throw();
//! Calculates \f$ (1+[x])^{[y]} \f$
lx_real xp1_pow_y(const lx_real &, const lx_real &) throw(); 
//! Calculates \f$ \sin([x]) \f$
lx_real sin(const lx_real &)throw();
//! Calculates \f$ \sin(n\cdot\pi+[x]) \f$
lx_real sin_n(const lx_real &x, const real& n) throw();
//! Calculates \f$ \cos([x]) \f$
lx_real cos(const lx_real &) throw();
//! Calculates \f$ \cos((n+1/2)\cdot\pi+[x]) \f$
lx_real cos_n(const lx_real &x, const real& n) throw();
//! Calculates \f$ \tan([x]) \f$
lx_real tan(const lx_real &) throw();
//! Calculates \f$ \cot([x]) \f$
lx_real cot(const lx_real &) throw();
//! Calculates \f$ \sqrt{1+[x]^2} \f$
lx_real sqrt1px2(const lx_real &) throw();
//! Calculates \f$ \arctan([x]) \f$
lx_real atan(const lx_real &) throw();
//! Calculates \f$ \sqrt{1-[x]^2} \f$
lx_real sqrt1mx2(const lx_real &) throw();
//! Calculates \f$ \sqrt{[x]^2-1} \f$
lx_real sqrtx2m1(const lx_real &) throw();
//! Calculates \f$ \arcsin([x]) \f$
lx_real asin(const lx_real & ) throw();
//! Calculates \f$ \arccos([x]) \f$
lx_real acos(const lx_real &) throw();
//! Calculates \f$ \mbox{arccot}([x]) \f$
lx_real acot(const lx_real &) throw();
//! Calculates \f$ \sinh([x]) \f$
lx_real sinh(const lx_real &) throw();
//! Calculates \f$ \cosh([x]) \f$
lx_real cosh(const lx_real &) throw();
//! Calculates \f$ \tanh([x]) \f$
lx_real tanh(const lx_real &) throw();
//! Calculates \f$ \coth([x]) \f$
lx_real coth(const lx_real &) throw();
//! Calculates \f$ \sqrt{[x]+1}-1} \f$
lx_real sqrtp1m1(const lx_real &) throw();
//! Calculates \f$ \mbox{arcsinh}([x]) \f$
lx_real asinh(const lx_real &) throw();
//! Calculates \f$ \mbox{arccosh}([x]) \f$
lx_real acosh(const lx_real &) throw();
//! Calculates \f$ \mbox{arccosh}(1+[x]) \f$
lx_real acoshp1(const lx_real &) throw();
//! Calculates \f$ \mbox{arctanh}([x]) \f$
lx_real atanh(const lx_real &) throw();
//! Calculates \f$ \mbox{arctanh}(1-[x]) \f$
lx_real atanh1m(const lx_real &) throw();
//! Calculates \f$ \mbox{arctanh}(-1+[x]) \f$
lx_real atanhm1p(const lx_real &) throw();
//! Calculates \f$ \mbox{arccoth}([x]) \f$
lx_real acoth(const lx_real &) throw();
//! Calculates \f$ \mbox{arccoth}(+1+[x]) \f$
lx_real acothp1(const lx_real &) throw();
//! Calculates \f$ \mbox{arctanh}(-1-[x]) \f$
lx_real acothm1m(const lx_real &) throw();
//! Calculates \f$ \sqrt{[x]^2 + [y]^2} \f$
lx_real sqrtx2y2(const lx_real &, const lx_real &) throw();
//! Calculates \f$ \ln(\sqrt{[x]^2 + [y]^2}) \f$
lx_real ln_sqrtx2y2(const lx_real &, const lx_real &) throw();
//! Calculates \f$ \sqrt[n]{[x]} \f$
lx_real sqrt(const lx_real &, int) throw();

} // namespace cxsc

#endif
